==> change_labels-1.0.0.tar.gz: change_labels/src/AutoEventSubscriber/ChangeAddAnotherLabelSubscriber.php <==
<?php

namespace Drupal\change_labels\AutoEventSubscriber;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\field_event_dispatcher\Event\Field\FieldWidgetThirdPartySettingsFormEvent;
use Drupal\field_event_dispatcher\Event\Field\WidgetMultivalueFormAlterEvent;
use Drupal\hook_event_dispatcher\HookEventDispatcherInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Change labels event subscriber.
 */
class ChangeAddAnotherLabelSubscriber implements EventSubscriberInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      HookEventDispatcherInterface::FIELD_WIDGET_THIRD_PARTY_SETTINGS_FORM => ['addSettings'],
      HookEventDispatcherInterface::WIDGET_MULTIVALUE_FORM_ALTER => ['alterForm'],
    ];
  }

  /**
   * Event handler for the third party settings of a widget.
   *
   * @param \Drupal\field_event_dispatcher\Event\Field\FieldWidgetThirdPartySettingsFormEvent $event
   *   Triggering event.
   */
  public function addSettings(FieldWidgetThirdPartySettingsFormEvent $event) {
    if ($event->getFieldDefinition()->getFieldStorageDefinition()->getCardinality() === 1) {
      return;
    }

    $element = [];
    $element['add_another'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Button label for "Add another"'),
      '#default_value' => $event->getPlugin()->getThirdPartySetting('change_labels', 'add_another'),
    ];
    $event->addElements('change_labels', $element);
  }

  /**
   * Event handler for altering a widget.
   *
   * @param \Drupal\field_event_dispatcher\Event\Field\WidgetMultivalueFormAlterEvent $event
   *   Triggering event.
   */
  public function alterForm(WidgetMultivalueFormAlterEvent $event) {
    $settings = $event->getContext()['widget']->getThirdPartySetting('change_labels', 'add_another');
    $elements = &$event->getElements();
    if ($settings && isset($elements['add_more'])) {
      $elements['add_more']['#value'] = $settings;
    }
  }

}

==> change_labels-1.0.2.tar.gz: change_labels/src/AutoEventSubscriber/ChangeAddAnotherLabelSubscriber.php <==
<?php

namespace Drupal\change_labels\AutoEventSubscriber;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\field_event_dispatcher\Event\Field\FieldWidgetThirdPartySettingsFormEvent;
use Drupal\field_event_dispatcher\Event\Field\WidgetCompleteFormAlterEvent;
use Drupal\field_event_dispatcher\FieldHookEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Change labels event subscriber.
 */
class ChangeAddAnotherLabelSubscriber implements EventSubscriberInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      FieldHookEvents::FIELD_WIDGET_THIRD_PARTY_SETTINGS_FORM => ['addSettings'],
      FieldHookEvents::WIDGET_COMPLETE_FORM_ALTER => ['alterForm'],
    ];
  }

  /**
   * Event handler for the third party settings of a widget.
   *
   * @param \Drupal\field_event_dispatcher\Event\Field\FieldWidgetThirdPartySettingsFormEvent $event
   *   Triggering event.
   */
  public function addSettings(FieldWidgetThirdPartySettingsFormEvent $event) {
    if ($event->getFieldDefinition()->getFieldStorageDefinition()->getCardinality() === 1) {
      return;
    }

    $element = [];
    $element['add_another'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Button label for "Add another"'),
      '#default_value' => $event->getPlugin()->getThirdPartySetting('change_labels', 'add_another'),
    ];
    $event->addElements('change_labels', $element);
  }

  /**
   * Event handler for altering a widget.
   *
   * @param \Drupal\field_event_dispatcher\Event\Field\WidgetCompleteFormAlterEvent $event
   *   Triggering event.
   */
  public function alterForm(WidgetCompleteFormAlterEvent $event) {
    $settings = $event->getContext()['widget']->getThirdPartySetting('change_labels', 'add_another');
    $elements = &$event->getElements();
    if ($settings && isset($elements['add_more'])) {
      $elements['add_more']['#value'] = $settings;
    }
  }

}
